import { world, system, Player, Entity } from '@minecraft/server';

import { ActionFormData, ModalFormData, MessageFormData } from "@minecraft/server-ui";

world.afterEvents.blockPlace.subscribe((eventData) => {
  const placedBlock = eventData.block;
  const player = eventData.player;

  const radarMob = world.getDimension("overworld").getEntities();
  const sirenMob = world.getDimension("overworld").getEntities();

  for (let radar of radarMob) {
    if (radar.typeId === "agp:decoy_radar") {
      if (player && placedBlock.typeId === "bridge:tornado_radar_block") {
        const distance = radar.location.y - placedBlock.location.y;
        player.runCommandAsync(`say ${distance}`);
        if (distance <= 0.35 && distance > 0) {
          if (radar.nameTag === "NoUser" && !radar.hasTag("Taken")) {
            radar.addTag("Taken");
            radar.nameTag = `${player.name}`;
          }
        }
      }
    }
  }
  for (let siren of sirenMob) {
    if (player && placedBlock.typeId === "bridge:tornado_siren_block") {
      const distance = siren.location.y - placedBlock.location.y;
      player.runCommandAsync(`say ${distance}`);
      if (distance <= 0.35 && distance > 0) {
        if (siren.nameTag === "NoUser" && !siren.hasTag("Taken")) {
          siren.addTag("Taken");
          siren.nameTag = `${player.name}`;
        }
      }
    }
  }
})
world.afterEvents.entityHit.subscribe((eventData) => {
  const player = eventData.entity;
  const hitBlock = eventData.hitBlock;

  const radarMob = world.getDimension("overworld").getEntities();
  const sirenMob = world.getDimension("overworld").getEntities();

  for (let radar of radarMob) {
    if (hitBlock && player instanceof Player) {
      if (hitBlock.typeId === "bridge:tornado_radar_block" && player.isSneaking) {
        if (radar.typeId === "agp:decoy_radar") {
          const distance = radar.location.y - hitBlock.location.y;
          if (distance <= 0.35 && distance > 0) {
            if (radar.nameTag === player.name) {
              RadarForm(player, hitBlock, radar, distance);
              return;
            }
            if (radar.nameTag !== player.name) {
              player.runCommandAsync(`tellraw @s {"rawtext": [{"text": "§4Sorry ${player.nameTag}, but this Radar GUI is already owned by ${radar.nameTag}"}]}`);
              player.playSound("playsound note.bass @s");
              return;
            }
          }
        }
      }
    }
  }
  for (let siren of sirenMob) {
    if (hitBlock && player instanceof Player) {
      if (hitBlock.typeId === "bridge:tornado_siren_block" && player.isSneaking) {
        if (siren.typeId === "agp:decoy_siren") {
          const distance = siren.location.y - hitBlock.location.y;
          if (distance <= 0.35 && distance > 0) {
            if (siren.nameTag === player.name) {
              player.runCommand('playsound note.bass @s');
              player.runCommand(`tellraw @s {"rawtext":[{"text":"§cSorry ${player.nameTag}, but this menu is currently unavailable!"}]}`);
              return;
            }
            if (siren.nameTag !== player.name) {
              player.runCommandAsync(`tellraw @s {"rawtext": [{"text": "§4Sorry ${player.nameTag}, but this Siren GUI is already owned by ${siren.nameTag}"}]}`);
              player.playSound("playsound note.bass @s");
              return;
            }
          }
        }
      }
    }
  }
});
function SirenForm(player) {
  const SF = new ActionFormData();
  SF.title("Siren Config Menu");
  SF.body("Edit certain aspects about the tornado siren block!");
  SF.button("Particles");
  SF.button("Siren Sounds");
  SF.show(player).then(finalize => {
    if (finalize.selection == 0) {
      SirenFormParticles(player);
    }
  })
}
function SirenFormParticles(player) {
  const SFP = new ModalFormData();
  SFP.title("Siren Config Menu - §3Particles");
  SFP.toggle("Siren Activated Particle", true);
  SFP.toggle("Siren Deactivated Particle", true);
  SFP.show(player).then(finalize => {
    if (finalize.formValues[0] == true) {
      player.runCommandAsync(`tellraw @s {"rawtext": [{"text": "§cSiren Activated Particle: §aTrue"}]}`);
      player.runCommandAsync(`tag @s remove SAP`);
    }
    if (finalize.formValues[0] == false) {
      player.runCommandAsync(`tellraw @s {"rawtext": [{"text": "§cSiren Activated Particle: §afalse"}]}`);
      player.runCommandAsync(`tag @s add SAP`);
    }
  })
}

function RadarForm(player, hitBlock, radar) {
  if (hitBlock.typeId === "bridge:tornado_radar_block") {
    if (radar.typeId === "agp:decoy_radar") {
      const distance = radar.location.y - hitBlock.location.y;
      if (distance <= 0.35 && distance > 0) {
        const RF = new ActionFormData();
        RF.title("Radar Config Menu");
        RF.body("customize the radar, with a large variety of options to choose from!");
        RF.button("Radar Types");
        RF.button("Board Icons");
        RF.button("§cStorm Displays");
        RF.show(player).then(finalize => {
          if (finalize.selection === 0) {
            RadarFormTypes(player, hitBlock, radar);
          }
          if (finalize.selection === 1) {
            RadarFormIcons(player, hitBlock, radar);
          }
          if (finalize.selection === 2) {
            player.runCommand('playsound note.bass @s');
            player.runCommand(`tellraw @s {"rawtext":[{"text":"§cSorry ${player.nameTag}, but this menu is currently unavailable!"}]}`);
          }
        })
      }
    }
  }
}
function RadarFormTypes(player, hitBlock, radar) {
  if (hitBlock.typeId === "bridge:tornado_radar_block") {
    if (radar.typeId === "agp:decoy_radar") {
      const distance = radar.location.y - hitBlock.location.y;
      if (distance <= 0.35 && distance > 0) {
        const RF = new ModalFormData();
        RF.title("Radar Config Menu - Types");
        RF.dropdown("Radar Type", ["Classic", "Realtime-Tracking", "Visual"], 0);
        RF.show(player).then(finalize => {
          if (finalize.formValues[0] === 0) {
            radar.removeTag("RMRealtime");
            radar.removeTag("RMRealtimeVisual");
          }
          if (finalize.formValues[0] === 1) {
            radar.addTag("RMRealtime");
            radar.removeTag("RMRealtimeVisual");
          }
          if (finalize.formValues[0] === 2) {
            radar.addTag("RMRealtimeVisual");
            radar.removeTag("RMRealtime");
          }
        })
      }
    }
  }
}
function RadarFormIcons(player, hitBlock, radar) {
  if (hitBlock.typeId === "bridge:tornado_radar_block") {
    if (radar.typeId === "agp:decoy_radar") {
      const distance = radar.location.y - hitBlock.location.y;
      if (distance <= 0.35 && distance > 0) {
        const RF = new ModalFormData();
        RF.title("Radar Config Menu - Icons");
        RF.toggle("Show Center Icon", true);
        RF.toggle("Show North Icon", true);
        RF.toggle("Show South Icon", true);
        RF.toggle("Show East Icon", true);
        RF.toggle("Show West Icon", true);
        RF.toggle("Show Board", true);
        RF.show(player).then(finalize => {
          if (finalize.formValues[0] == true) {
            radar.removeTag("RCI");
          }
          if (finalize.formValues[0] == false) {
            radar.addTag("RCI");
          }

          if (finalize.formValues[1] == true) {
            radar.removeTag("RNI");
          }
          if (finalize.formValues[1] == false) {
            radar.addTag("RNI");
          }
          if (finalize.formValues[2] == true) {
            radar.removeTag("RSI");
          }
          if (finalize.formValues[2] == false) {
            radar.addTag("RSI");
          }
          if (finalize.formValues[3] == true) {
            radar.removeTag("REI");
          }
          if (finalize.formValues[3] == false) {
            radar.addTag("REI");
          }
          if (finalize.formValues[4] == true) {
            radar.removeTag("RWI");
          }
          if (finalize.formValues[4] == false) {
            radar.addTag("RWI");
          }
          if (finalize.formValues[5] == true) {
            radar.removeTag("RBI");
          }
          if (finalize.formValues[5] == false) {
            radar.addTag("RBI");
          }
        })
      }
    }
  }
}
function RadarFormDisplays(player, hitBlock, radar) {
  const distance = hitBlock.location.y - radar.location.y;
  if (radar.typeId === "agp:decoy_radar" && distance <= 0.35 && distance > 0) {
    const RF = new ModalFormData();
    RF.title("Radar Config Menu - Displays");
    RF.toggle("Show EF0", true);
    RF.toggle("Show EF1", true);
    RF.toggle("Show EF2", true);
    RF.toggle("Show EF3", true);
    RF.toggle("Show Died-Down EF0", true);
    RF.toggle("Show Died-Down EF1", true);
    RF.toggle("Show Died-Down EF2", true);
    RF.toggle("Show Died-Down EF3", true);
    RF.show(player).then(finalize => {
      if (finalize.formValues[0] == true) {
        radar.removeTag("ORI");
        player.runCommandAsync("say true");
      }
      if (finalize.formValues[0] == false) {
        radar.addTag("ORI");
        player.runCommandAsync("say false");
      }
    })
  }
} //Made by ItzJeremicer